==> estateplat-common-1.2.4-20191223.080819-229-sources.jar: cn/gtmap/estateplat/model/information/core/XxXm.java <==
package cn.gtmap.estateplat.model.information.core;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2019-12-17
 * @description 项目表
 */
@Table(name = "xx_xm")
public class XxXm implements InsertVo {
    @Id
    private String proid;//主键
    @Column
    private String slbh;//受理编号
    @Column
    private String xmzt;//项目状态
    @Column
    private Date cjsj;//创建时间
    @Column
    private String cjr;//创建人
    @Column
    private Date bjsj;//办结时间
    @Column
    private String bz; //备注

    public String getSlbh() {
        return slbh;
    }

    public void setSlbh(String slbh) {
        this.slbh = slbh;
    }

    public String getXmzt() {
        return xmzt;
    }

    public void setXmzt(String xmzt) {
        this.xmzt = xmzt;
    }

    public Date getCjsj() {
        return cjsj;
    }

    public void setCjsj(Date cjsj) {
        this.cjsj = cjsj;
    }

    public String getCjr() {
        return cjr;
    }

    public void setCjr(String cjr) {
        this.cjr = cjr;
    }

    public Date getBjsj() {
        return bjsj;
    }

    public void setBjsj(Date bjsj) {
        this.bjsj = bjsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }
}

==> estateplat-common-1.2.4-20200114.064255-251-sources.jar: cn/gtmap/estateplat/model/information/core/XxXm.java <==
package cn.gtmap.estateplat.model.information.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2019-12-17
 * @description 项目表
 */
@Table(name = "xx_xm")
public class XxXm implements InsertVo {
    @Id
    private String proid;//主键
    private String slbh;//受理编号
    private String xmzt;//项目状态
    private String wiid; //工作流定义ID
    private String ywlx;//业务类型
    private Date cjsj;//创建时间
    private String cjr;//创建人
    private Date bjsj;//办结时间
    private String bz; //备注

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getSlbh() {
        return slbh;
    }

    public void setSlbh(String slbh) {
        this.slbh = slbh;
    }

    public String getXmzt() {
        return xmzt;
    }

    public void setXmzt(String xmzt) {
        this.xmzt = xmzt;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public String getYwlx() {
        return ywlx;
    }

    public void setYwlx(String ywlx) {
        this.ywlx = ywlx;
    }

    public Date getCjsj() {
        return cjsj;
    }

    public void setCjsj(Date cjsj) {
        this.cjsj = cjsj;
    }

    public String getCjr() {
        return cjr;
    }

    public void setCjr(String cjr) {
        this.cjr = cjr;
    }

    public Date getBjsj() {
        return bjsj;
    }

    public void setBjsj(Date bjsj) {
        this.bjsj = bjsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}
